@@ -1,5 +1,5 @@
 #-----------------------------------------------------------------------------
-# Copyright (c) 2012 - 2022, Anaconda, Inc., and Bokeh Contributors.
+# Copyright (c) 2012 - 2023, Anaconda, Inc., and Bokeh Contributors.
 # All rights reserved.
 #
 # The full license is in the file LICENSE.txt, distributed with this software.
@@ -60,7 +60,7 @@ def property_link(obj: Any) -> str:
 
 Fn: TypeAlias = Callable[[Any], str]
 
-def register_type_link(cls: Type[Any]) -> Callable[[Fn], Fn]:
+def register_type_link(cls: type[Any]) -> Callable[[Fn], Fn]:
     def decorator(func: Fn):
         _type_links[cls] = func
         return func
