@@ -32,6 +32,7 @@ from os.path import (
     join,
     normpath,
 )
+from pathlib import Path
 from typing import (
     TYPE_CHECKING,
     Callable,
@@ -44,10 +45,9 @@ from typing import (
 from ..core.templates import CSS_RESOURCES, JS_RESOURCES
 from ..document.document import Document
 from ..model import Model
-from ..resources import BaseResources, Resources
+from ..resources import Resources
 from ..settings import settings
 from ..util.compiler import bundle_models
-from ..util.warnings import warn
 from .util import contains_tex_string, is_tex_string
 
 if TYPE_CHECKING:
@@ -145,46 +145,28 @@ class Bundle:
         elif isinstance(artifact, Style):
             self.css_raw.append(artifact.content)
 
-def bundle_for_objs_and_resources(objs: Sequence[Model | Document] | None,
-        resources: BaseResources | tuple[BaseResources | None, BaseResources | None] | None) -> Bundle:
+def bundle_for_objs_and_resources(objs: Sequence[Model | Document] | None, resources: Resources | None) -> Bundle:
     ''' Generate rendered CSS and JS resources suitable for the given
     collection of Bokeh objects
 
     Args:
         objs (seq[Model or Document]) :
 
-        resources (BaseResources or tuple[BaseResources])
+        resources (Resources)
 
     Returns:
         Bundle
 
     '''
-    # Any env vars will overide a local default passed in
-    resources = settings.resources(default=resources)
-    if isinstance(resources, str):
-        resources = Resources(mode=resources)
-
-    if resources is None or isinstance(resources, BaseResources):
-        js_resources = css_resources = resources
-    elif isinstance(resources, tuple) and len(resources) == 2 and all(r is None or isinstance(r, BaseResources) for r in resources):
-        js_resources, css_resources = resources
-
-        if js_resources and not css_resources:
-            warn('No Bokeh CSS Resources provided to template. If required you will need to provide them manually.')
-
-        if css_resources and not js_resources:
-            warn('No Bokeh JS Resources provided to template. If required you will need to provide them manually.')
-    else:
-        raise ValueError(f"expected Resources or a pair of optional Resources, got {resources!r}")
-
     if objs is not None:
-        all_objs = _all_objs(objs)
+        all_objs    = _all_objs(objs)
         use_widgets = _use_widgets(all_objs)
         use_tables  = _use_tables(all_objs)
         use_gl      = _use_gl(all_objs)
         use_mathjax = _use_mathjax(all_objs)
     else:
         # XXX: force all components on server and in notebook, because we don't know in advance what will be used
+        all_objs    = None
         use_widgets = True
         use_tables  = True
         use_gl      = True
@@ -195,30 +177,23 @@ def bundle_for_objs_and_resources(objs: Sequence[Model | Document] | None,
     css_files: list[str] = []
     css_raw: list[str] = []
 
-    from copy import deepcopy
+    if resources is not None:
+        components = list(resources.components)
+        if not use_widgets: components.remove("bokeh-widgets")
+        if not use_tables:  components.remove("bokeh-tables")
+        if not use_gl:      components.remove("bokeh-gl")
+        if not use_mathjax: components.remove("bokeh-mathjax")
 
-    if js_resources:
-        js_resources = deepcopy(js_resources)
-        if not use_widgets and "bokeh-widgets" in js_resources.js_components:
-            js_resources.js_components.remove("bokeh-widgets")
-        if not use_tables and "bokeh-tables" in js_resources.js_components:
-            js_resources.js_components.remove("bokeh-tables")
-        if not use_gl and "bokeh-gl" in js_resources.js_components:
-            js_resources.js_components.remove("bokeh-gl")
-        if not use_mathjax and "bokeh-mathjax" in js_resources.js_components:
-            js_resources.js_components.remove("bokeh-mathjax")
+        resources = resources.clone(components=components)
 
-        js_files.extend(js_resources.js_files)
-        js_raw.extend(js_resources.js_raw)
+        js_files.extend(resources.js_files)
+        js_raw.extend(resources.js_raw)
 
-    if css_resources:
-        css_resources = deepcopy(css_resources)
-        css_files.extend(css_resources.css_files)
-        css_raw.extend(css_resources.css_raw)
+        css_files.extend(resources.css_files)
+        css_raw.extend(resources.css_raw)
 
-    if js_resources:
-        extensions = _bundle_extensions(all_objs if objs else None, js_resources)
-        mode = js_resources.mode if resources is not None else "inline"
+        extensions = _bundle_extensions(all_objs if objs else None, resources)
+        mode = resources.mode
         if mode == "inline":
             js_raw.extend([ Resources._inline(bundle.artifact_path) for bundle in extensions ])
         elif mode == "server":
@@ -232,12 +207,12 @@ def bundle_for_objs_and_resources(objs: Sequence[Model | Document] | None,
         else:
             js_files.extend([ bundle.artifact_path for bundle in extensions ])
 
-    models = [ obj.__class__ for obj in all_objs ] if objs else None
+    models = [ obj.__class__ for obj in all_objs ] if all_objs else None
     ext = bundle_models(models)
     if ext is not None:
         js_raw.append(ext)
 
-    return Bundle(js_files, js_raw, css_files, css_raw, js_resources.hashes if js_resources else {})
+    return Bundle(js_files, js_raw, css_files, css_raw, resources.hashes if resources else {})
 
 #-----------------------------------------------------------------------------
 # Private API
@@ -277,15 +252,17 @@ class Pkg(TypedDict, total=False):
     module: str
     main: str
 
-extension_dirs: dict[str, str] = {} # name -> path
+extension_dirs: dict[str, Path] = {}
 
-def _bundle_extensions(all_objs: set[Model], resources: Resources) -> list[ExtensionEmbed]:
+def _bundle_extensions(objs: set[Model] | None, resources: Resources) -> list[ExtensionEmbed]:
     names: set[str] = set()
     bundles: list[ExtensionEmbed] = []
 
     extensions = [".min.js", ".js"] if resources.minified else [".js"]
 
-    for obj in all_objs if all_objs is not None else Model.model_class_reverse_map.values():
+    all_objs = objs if objs is not None else Model.model_class_reverse_map.values()
+
+    for obj in all_objs:
         if hasattr(obj, "__implementation__"):
             continue
         name = obj.__view_module__.split(".")[0]
@@ -347,7 +324,7 @@ def _bundle_extensions(all_objs: set[Model], resources: Resources) -> list[Exten
             else:
                 raise ValueError(f"can't resolve artifact path for '{name}' extension")
 
-        extension_dirs[name] = artifacts_dir
+        extension_dirs[name] = Path(artifacts_dir)
         server_url = f"{server_prefix}/{server_path}"
         embed = ExtensionEmbed(artifact_path, server_url, cdn_url)
         bundles.append(embed)
