@@ -1,5 +1,5 @@
 #-----------------------------------------------------------------------------
-# Copyright (c) 2012 - 2022, Anaconda, Inc., and Bokeh Contributors.
+# Copyright (c) 2012 - 2023, Anaconda, Inc., and Bokeh Contributors.
 # All rights reserved.
 #
 # The full license is in the file LICENSE.txt, distributed with this software.
@@ -45,7 +45,7 @@ from ..core.templates import (
 )
 from ..document.document import DEFAULT_TITLE, Document
 from ..model import Model
-from ..resources import CSSResources, JSResources, Resources
+from ..resources import Resources
 from ..themes import Theme
 from .bundle import Script, bundle_for_objs_and_resources
 from .elements import html_page_for_render_items, script_for_render_items
@@ -258,7 +258,7 @@ def components(models: Model | Sequence[Model] | dict[str, Model], wrap_script:
 
     # now convert dict to list, saving keys in the same order
     model_keys = None
-    dict_type: Type[dict[Any, Any]] = dict
+    dict_type: type[dict[Any, Any]] = dict
     if isinstance(models, dict):
         dict_type = models.__class__
         model_keys = models.keys()
@@ -294,7 +294,7 @@ def components(models: Model | Sequence[Model] | dict[str, Model], wrap_script:
     return script, result
 
 def file_html(models: Model | Document | Sequence[Model],
-              resources: Resources | tuple[JSResources | None, CSSResources | None] | None,
+              resources: Resources | None,
               title: str | None = None,
               template: Template | str = FILE,
               template_variables: dict[str, Any] = {},
@@ -311,7 +311,7 @@ def file_html(models: Model | Document | Sequence[Model],
         models (Model or Document or seq[Model]) : Bokeh object or objects to render
             typically a Model or Document
 
-        resources (Resources or tuple(JSResources or None, CSSResources or None)) :
+        resources (Resources) :
             A resource configuration for Bokeh JS & CSS assets.
 
         title (str, optional) :
