@@ -1,5 +1,5 @@
 #-----------------------------------------------------------------------------
-# Copyright (c) 2012 - 2022, Anaconda, Inc., and Bokeh Contributors.
+# Copyright (c) 2012 - 2023, Anaconda, Inc., and Bokeh Contributors.
 # All rights reserved.
 #
 # The full license is in the file LICENSE.txt, distributed with this software.
@@ -38,7 +38,7 @@ from ..model import Model, collect_models
 from ..settings import settings
 from ..themes.theme import Theme
 from ..util.dataclasses import dataclass, field
-from ..util.serialization import make_globally_unique_id
+from ..util.serialization import make_globally_unique_css_safe_id, make_globally_unique_id
 
 if TYPE_CHECKING:
     from ..document.document import DocJson
@@ -140,12 +140,12 @@ def OutputDocumentFor(objs: Sequence[Model], apply_theme: Theme | type[FromCurdo
     docs = {obj.document for obj in objs if obj.document is not None}
 
     if always_new:
-        def finish() -> None:
+        def finish() -> None:  # noqa
             _dispose_temp_doc(objs)
         doc = _create_temp_doc(objs)
     else:
         if len(docs) == 0:
-            doc = Document()
+            doc = _new_doc()
             for model in objs:
                 doc.add_root(model)
 
@@ -268,7 +268,7 @@ class RenderRoots:
                 if root.name == key:
                     break
             else:
-                raise ValueError("root with '%s' name not found" % key)
+                raise ValueError(f"root with {key!r} name not found")
 
         return RenderRoot(elementid, root.id, root.name, root.tags)
 
@@ -320,10 +320,10 @@ def standalone_docs_json_and_render_items(models: Model | Document | Sequence[Mo
         (docid, roots) = docs[doc]
 
         if model is not None:
-            roots[model] = make_globally_unique_id()
+            roots[model] = make_globally_unique_css_safe_id()
         else:
             for model in doc.roots:
-                roots[model] = make_globally_unique_id()
+                roots[model] = make_globally_unique_css_safe_id()
 
     docs_json: dict[ID, DocJson] = {}
     for doc, (docid, _) in docs.items():
@@ -397,8 +397,17 @@ be used. For more information on building and running Bokeh applications, see:
     https://docs.bokeh.org/en/latest/docs/user_guide/server.html
 """
 
-def _create_temp_doc(models: Sequence[Model]) -> Document:
+def _new_doc() -> Document:
+    # TODO: embed APIs need to actually respect the existing document's
+    # configuration, but for now this is better than nothing.
+    from ..io import curdoc
     doc = Document()
+    callbacks = curdoc().callbacks._js_event_callbacks
+    doc.callbacks._js_event_callbacks.update(callbacks)
+    return doc
+
+def _create_temp_doc(models: Sequence[Model]) -> Document:
+    doc = _new_doc()
     for m in models:
         doc.models[m.id] = m
         m._temp_document = doc
