@@ -1,5 +1,5 @@
 #-----------------------------------------------------------------------------
-# Copyright (c) 2012 - 2022, Anaconda, Inc., and Bokeh Contributors.
+# Copyright (c) 2012 - 2023, Anaconda, Inc., and Bokeh Contributors.
 # All rights reserved.
 #
 # The full license is in the file LICENSE.txt, distributed with this software.
@@ -21,7 +21,6 @@ log = logging.getLogger(__name__)
 #-----------------------------------------------------------------------------
 
 # Standard library imports
-import warnings
 from contextlib import contextmanager
 from typing import (
     Any,
@@ -74,11 +73,12 @@ from ..core.validation.errors import (
 from ..core.validation.warnings import MISSING_RENDERERS
 from ..model import Model
 from ..util.strings import nice_join
+from ..util.warnings import warn
 from .annotations import Annotation, Legend, Title
 from .axes import Axis
 from .glyphs import Glyph
 from .grids import Grid
-from .layouts import LayoutDOM, TracksSizing
+from .layouts import GridCommon, LayoutDOM
 from .ranges import (
     DataRange1d,
     FactorRange,
@@ -467,22 +467,16 @@ class Plot(LayoutDOM):
         if self.x_scale is not None:
             for rng in x_ranges:
                 if isinstance(rng, (DataRange1d, Range1d)) and not isinstance(self.x_scale, (LinearScale, LogScale)):
-                    incompatible.append("incompatibility on x-dimension: %s, %s" %(rng, self.x_scale))
+                    incompatible.append(f"incompatibility on x-dimension: {rng}, {self.x_scale}")
                 elif isinstance(rng, FactorRange) and not isinstance(self.x_scale, CategoricalScale):
-                    incompatible.append("incompatibility on x-dimension: %s/%s" %(rng, self.x_scale))
-                # special case because CategoricalScale is a subclass of LinearScale, should be removed in future
-                if isinstance(rng, (DataRange1d, Range1d)) and isinstance(self.x_scale, CategoricalScale):
-                    incompatible.append("incompatibility on x-dimension: %s, %s" %(rng, self.x_scale))
+                    incompatible.append(f"incompatibility on x-dimension: {rng}, {self.x_scale}")
 
         if self.y_scale is not None:
             for rng in y_ranges:
                 if isinstance(rng, (DataRange1d, Range1d)) and not isinstance(self.y_scale, (LinearScale, LogScale)):
-                    incompatible.append("incompatibility on y-dimension: %s/%s" %(rng, self.y_scale))
+                    incompatible.append(f"incompatibility on y-dimension: {rng}, {self.y_scale}")
                 elif isinstance(rng, FactorRange) and not isinstance(self.y_scale, CategoricalScale):
-                    incompatible.append("incompatibility on y-dimension: %s/%s" %(rng, self.y_scale))
-                # special case because CategoricalScale is a subclass of LinearScale, should be removed in future
-                if isinstance(rng, (DataRange1d, Range1d)) and isinstance(self.y_scale, CategoricalScale):
-                    incompatible.append("incompatibility on y-dimension: %s, %s" %(rng, self.y_scale))
+                    incompatible.append(f"incompatibility on y-dimension: {rng}, {self.y_scale}")
 
         if incompatible:
             return ", ".join(incompatible) + " [%s]" % self
@@ -860,8 +854,8 @@ class Plot(LayoutDOM):
     In this case we render newly appended points only after the last stream.
     """)
 
-class GridPlot(LayoutDOM):
-    """
+class GridPlot(LayoutDOM, GridCommon):
+    """ Collection of plots and other layoutables on arranged on a rectangular grid.
 
     """
 
@@ -886,22 +880,6 @@ class GridPlot(LayoutDOM):
     index and optional row and column spans (the defaul span is 1).
     """)
 
-    rows = Nullable(TracksSizing, default="max-content", help="""
-    Describes how the grid should maintain its rows' heights.
-    """)
-
-    cols = Nullable(TracksSizing, default="max-content", help="""
-    Describes how the grid should maintain its columns' widths.
-    """)
-
-    spacing = Either(Int, Tuple(Int, Int), default=0, help="""
-    The gap between children (in pixels).
-
-    Either a number, if spacing is the same for both dimensions, or a pair
-    of numbers indicating spacing in the vertical and horizontal dimensions
-    respectively.
-    """)
-
     @error(REPEATED_LAYOUT_CHILD)
     def _check_repeated_layout_children(self):
         children = [ child[0] for child in self.children ]
@@ -918,7 +896,7 @@ class GridPlot(LayoutDOM):
 
 def _check_conflicting_kwargs(a1, a2, kwargs):
     if a1 in kwargs and a2 in kwargs:
-        raise ValueError("Conflicting properties set on plot: %r and %r" % (a1, a2))
+        raise ValueError(f"Conflicting properties set on plot: {a1!r} and {a2!r}")
 
 class _list_attr_splat(list):
     def __setattr__(self, attr, value):
@@ -934,7 +912,7 @@ class _list_attr_splat(list):
         try:
             return _list_attr_splat([getattr(x, attr) for x in self])
         except Exception:
-            raise AttributeError("Trying to access %r attribute on a 'splattable' list, but list items have no %r attribute" % (attr, attr))
+            raise AttributeError(f"Trying to access {attr!r} attribute on a 'splattable' list, but list items have no {attr!r} attribute")
 
     def __dir__(self):
         if len({type(x) for x in self}) == 1:
@@ -951,7 +929,7 @@ Before legend properties can be set, you must add a Legend explicitly, or call a
 class _legend_attr_splat(_list_attr_splat):
     def __setattr__(self, attr, value):
         if not len(self):
-            warnings.warn(_LEGEND_EMPTY_WARNING % attr)
+            warn(_LEGEND_EMPTY_WARNING % attr)
         return super().__setattr__(attr, value)
 
 def _select_helper(args, kwargs):
