@@ -1,5 +1,5 @@
 #-----------------------------------------------------------------------------
-# Copyright (c) 2012 - 2022, Anaconda, Inc., and Bokeh Contributors.
+# Copyright (c) 2012 - 2023, Anaconda, Inc., and Bokeh Contributors.
 # All rights reserved.
 #
 # The full license is in the file LICENSE.txt, distributed with this software.
@@ -18,7 +18,6 @@ log = logging.getLogger(__name__)
 #-----------------------------------------------------------------------------
 
 # Standard library imports
-import warnings
 from typing import (
     TYPE_CHECKING,
     Any as TAny,
@@ -55,7 +54,7 @@ from ..core.properties import (
 from ..model import Model
 from ..util.deprecation import deprecated
 from ..util.serialization import convert_datetime_array
-from ..util.warnings import BokehUserWarning
+from ..util.warnings import BokehUserWarning, warn
 from .callbacks import CustomJS
 from .filters import AllIndices, Filter, IntersectionFilter
 from .selections import Selection, SelectionPolicy, UnionRenderers
@@ -208,7 +207,7 @@ class ColumnDataSource(ColumnarDataSource):
     ).accepts(
         Object("pandas.core.groupby.GroupBy"), lambda x: ColumnDataSource._data_from_groupby(x)
     ).asserts(lambda _, data: len({len(x) for x in data.values()}) <= 1,
-                 lambda obj, name, data: warnings.warn(
+                 lambda obj, name, data: warn(
                     "ColumnDataSource's columns must be of the same length. " +
                     "Current lengths: %s" % ", ".join(sorted(str((k, len(v))) for k, v in data.items())), BokehUserWarning))
 
@@ -413,7 +412,7 @@ class ColumnDataSource(ColumnarDataSource):
         try:
             del self.data[name]
         except (ValueError, KeyError):
-            warnings.warn("Unable to find column '%s' in data source" % name)
+            warn(f"Unable to find column '{name}' in data source")
 
     def stream(self, new_data: DataDict, rollover: int | None = None) -> None:
         ''' Efficiently update data source columns with new append-only data.
@@ -530,16 +529,14 @@ class ColumnDataSource(ColumnarDataSource):
         oldkeys = set(self.data.keys())
 
         if newkeys != oldkeys:
-            missing = oldkeys - newkeys
-            extra = newkeys - oldkeys
+            missing = sorted(oldkeys - newkeys)
+            extra = sorted(newkeys - oldkeys)
             if missing and extra:
-                raise ValueError(
-                    "Must stream updates to all existing columns (missing: %s, extra: %s)" % (", ".join(sorted(missing)), ", ".join(sorted(extra)))
-                )
+                raise ValueError(f"Must stream updates to all existing columns (missing: {', '.join(missing)}, extra: {', '.join(extra)})")
             elif missing:
-                raise ValueError("Must stream updates to all existing columns (missing: %s)" % ", ".join(sorted(missing)))
+                raise ValueError(f"Must stream updates to all existing columns (missing: {', '.join(missing)})")
             else:
-                raise ValueError("Must stream updates to all existing columns (extra: %s)" % ", ".join(sorted(extra)))
+                raise ValueError(f"Must stream updates to all existing columns (extra: {', '.join(extra)})")
 
         if needs_length_check:
             lengths: set[int] = set()
@@ -547,7 +544,7 @@ class ColumnDataSource(ColumnarDataSource):
             for _, x in new_data.items():
                 if isinstance(x, arr_types):
                     if len(x.shape) != 1:
-                        raise ValueError("stream(...) only supports 1d sequences, got ndarray with size %r" % (x.shape,))
+                        raise ValueError(f"stream(...) only supports 1d sequences, got ndarray with size {x.shape!r}")
                     lengths.add(x.shape[0])
                 else:
                     lengths.add(len(x))
@@ -664,7 +661,7 @@ class ColumnDataSource(ColumnarDataSource):
 
             dict(foo=[11, 12, 30], bar=[101, 200, 301])
 
-        For a more comprehensive complete example, see :bokeh-tree:`examples/howto/patch_app.py`.
+        For a more comprehensive example, see :bokeh-tree:`examples/server/app/patch_app.py`.
 
         '''
         extra = set(patches.keys()) - set(self.data.keys())
@@ -866,7 +863,7 @@ class AjaxDataSource(WebDataSource):
     This is necessary when used in conjunction with a ``FactorRange``, even
     if the columns in `data`` are empty.
 
-    A full example can be seen at :bokeh-tree:`examples/howto/ajax_source.py`
+    A full example can be seen at :bokeh-tree:`examples/basic/data/ajax_source.py`
 
     '''
 
