@@ -1,5 +1,5 @@
 #-----------------------------------------------------------------------------
-# Copyright (c) 2012 - 2022, Anaconda, Inc., and Bokeh Contributors.
+# Copyright (c) 2012 - 2023, Anaconda, Inc., and Bokeh Contributors.
 # All rights reserved.
 #
 # The full license is in the file LICENSE.txt, distributed with this software.
@@ -63,6 +63,7 @@ from ..core.properties import (
     Color,
     Date,
     Datetime,
+    DeprecatedAlias,
     Dict,
     Either,
     Enum,
@@ -77,7 +78,6 @@ from ..core.properties import (
     Override,
     Percent,
     Regex,
-    Required,
     Seq,
     String,
     Tuple,
@@ -169,8 +169,8 @@ class Tool(Model):
     # explicit __init__ to support Init signatures
     def __init__(self, *args, **kwargs) -> None:
         super().__init__(*args, **kwargs)
-
-    icon = Nullable(Either(Enum(ToolIcon), Regex(r"^\."), Image), help="""
+    #Image has to be first! see #12775, temporary fix
+    icon = Nullable(Either(Image, Enum(ToolIcon), Regex(r"^\.")), help="""
     An icon to display in the toolbar.
 
     The icon can provided as well known tool icon name, a CSS class selector,
@@ -295,6 +295,29 @@ class SelectTool(GestureTool):
     the selection, intersect with it or subtract from it.
     """)
 
+@abstract
+class RegionSelectTool(SelectTool):
+    ''' Base class for region selection tools (e.g. box, polygon, lasso).
+
+    '''
+
+    # explicit __init__ to support Init signatures
+    def __init__(self, *args, **kwargs) -> None:
+        super().__init__(*args, **kwargs)
+
+    continuous = Bool(False, help="""
+    Whether a selection computation should happen continuously during selection
+    gestures, or only once when the selection region is completed.
+    """)
+
+    select_every_mousemove = DeprecatedAlias("continuous", since=(3, 1, 0))
+
+    persistent = Bool(default=False, help="""
+    Whether the selection overlay should persist after selection gesture
+    is completed. This can be paired with setting ``editable = True`` on
+    the annotation, to allow to modify the selection.
+    """)
+
 @abstract
 class InspectTool(GestureTool):
     ''' A base class for tools that perform "inspections", e.g. ``HoverTool``.
@@ -392,15 +415,18 @@ class PanTool(Drag):
 DEFAULT_RANGE_OVERLAY = InstanceDefault(BoxAnnotation,
     syncable=False,
     level="overlay",
+    visible=True,
+    editable=True,
+    propagate_hover=True,
     fill_color="lightgrey",
     fill_alpha=0.5,
     line_color="black",
     line_alpha=1.0,
     line_width=0.5,
-    line_dash=[2,2],
+    line_dash=[2, 2],
 )
 
-class RangeTool(Drag):
+class RangeTool(Tool):
     ''' *toolbar icon*: |range_icon|
 
     The range tool allows the user to update range objects for either or both
@@ -427,6 +453,11 @@ class RangeTool(Drag):
     will span the entire x-dimension.
     """)
 
+    y_range = Nullable(Instance(Range1d), help="""
+    A range synchronized to the y-dimension of the overlay. If None, the overlay
+    will span the entire y-dimension.
+    """)
+
     x_interaction = Bool(default=True, help="""
     Whether to respond to horizontal pan motions when an ``x_range`` is present.
 
@@ -437,11 +468,6 @@ class RangeTool(Drag):
     update if the ``x_range`` is updated programmatically.)
     """)
 
-    y_range = Nullable(Instance(Range1d), help="""
-    A range synchronized to the y-dimension of the overlay. If None, the overlay
-    will span the entire y-dimension.
-    """)
-
     y_interaction = Bool(default=True, help="""
     Whether to respond to vertical pan motions when a ``y_range`` is present.
 
@@ -627,7 +653,7 @@ class TapTool(Tap, SelectTool):
 
     .. note::
         Selections can be comprised of multiple regions, even those
-        made by different selection tools. Hold down the <<shift>> key
+        made by different selection tools. Hold down the SHIFT key
         while making a selection to append the new selection to any
         previous selection that might exist.
 
@@ -742,10 +768,11 @@ class CrosshairTool(InspectTool):
     Stroke width in units of pixels.
     """)
 
-DEFAULT_BOX_OVERLAY = InstanceDefault(BoxAnnotation,
+DEFAULT_BOX_ZOOM_OVERLAY = InstanceDefault(BoxAnnotation,
     syncable=False,
     level="overlay",
     visible=False,
+    editable=False,
     top_units="canvas",
     left_units="canvas",
     bottom_units="canvas",
@@ -758,6 +785,23 @@ DEFAULT_BOX_OVERLAY = InstanceDefault(BoxAnnotation,
     line_dash=[4, 4],
 )
 
+DEFAULT_BOX_SELECT_OVERLAY = InstanceDefault(BoxAnnotation,
+    syncable=False,
+    level="overlay",
+    visible=False,
+    editable=True,
+    top_units="data",
+    left_units="data",
+    bottom_units="data",
+    right_units="data",
+    fill_color="lightgrey",
+    fill_alpha=0.5,
+    line_color="black",
+    line_alpha=1.0,
+    line_width=2,
+    line_dash=[4, 4],
+)
+
 class BoxZoomTool(Drag):
     ''' *toolbar icon*: |box_zoom_icon|
 
@@ -789,7 +833,7 @@ class BoxZoomTool(Drag):
     of the plot, and the vertical dimension can be controlled.
     """)
 
-    overlay = Instance(BoxAnnotation, default=DEFAULT_BOX_OVERLAY, help="""
+    overlay = Instance(BoxAnnotation, default=DEFAULT_BOX_ZOOM_OVERLAY, help="""
     A shaded annotation drawn to indicate the selection region.
     """)
 
@@ -870,7 +914,7 @@ class ZoomOutTool(PlotActionTool):
     that causes overall focus or aspect ratio to change.
     """)
 
-class BoxSelectTool(Drag, SelectTool):
+class BoxSelectTool(Drag, RegionSelectTool):
     ''' *toolbar icon*: |box_select_icon|
 
     The box selection tool allows users to make selections on a Plot by showing
@@ -891,11 +935,6 @@ class BoxSelectTool(Drag, SelectTool):
     def __init__(self, *args, **kwargs) -> None:
         super().__init__(*args, **kwargs)
 
-    select_every_mousemove = Bool(False, help="""
-    Whether a selection computation should happen on every mouse event, or only
-    once, when the selection region is completed. Default: False
-    """)
-
     dimensions = Enum(Dimensions, default="both", help="""
     Which dimensions the box selection is to be free in. By default, users may
     freely draw selections boxes with any dimensions. If only "width" is set,
@@ -905,7 +944,7 @@ class BoxSelectTool(Drag, SelectTool):
     plot, and the vertical dimension can be controlled.
     """)
 
-    overlay = Instance(BoxAnnotation, default=DEFAULT_BOX_OVERLAY, help="""
+    overlay = Instance(BoxAnnotation, default=DEFAULT_BOX_SELECT_OVERLAY, help="""
     A shaded annotation drawn to indicate the selection region.
     """)
 
@@ -918,8 +957,9 @@ DEFAULT_POLY_OVERLAY = InstanceDefault(PolyAnnotation,
     syncable=False,
     level="overlay",
     visible=False,
-    xs_units="canvas",
-    ys_units="canvas",
+    editable=True,
+    xs_units="data",
+    ys_units="data",
     fill_color="lightgrey",
     fill_alpha=0.5,
     line_color="black",
@@ -928,7 +968,7 @@ DEFAULT_POLY_OVERLAY = InstanceDefault(PolyAnnotation,
     line_dash=[4, 4]
 )
 
-class LassoSelectTool(Drag, SelectTool):
+class LassoSelectTool(Drag, RegionSelectTool):
     ''' *toolbar icon*: |lasso_select_icon|
 
     The lasso selection tool allows users to make selections on a Plot by
@@ -941,7 +981,7 @@ class LassoSelectTool(Drag, SelectTool):
 
     .. note::
         Selections can be comprised of multiple regions, even those made by
-        different selection tools. Hold down the <<shift>> key while making a
+        different selection tools. Hold down the SHIFT key while making a
         selection to append the new selection to any previous selection that
         might exist.
 
@@ -955,16 +995,13 @@ class LassoSelectTool(Drag, SelectTool):
     def __init__(self, *args, **kwargs) -> None:
         super().__init__(*args, **kwargs)
 
-    select_every_mousemove = Bool(True, help="""
-    Whether a selection computation should happen on every mouse event, or only
-    once, when the selection region is completed.
-    """)
-
     overlay = Instance(PolyAnnotation, default=DEFAULT_POLY_OVERLAY, help="""
     A shaded annotation drawn to indicate the selection region.
     """)
 
-class PolySelectTool(Tap, SelectTool):
+    continuous = Override(default=True)
+
+class PolySelectTool(Tap, RegionSelectTool):
     ''' *toolbar icon*: |poly_select_icon|
 
     The polygon selection tool allows users to make selections on a
@@ -978,7 +1015,7 @@ class PolySelectTool(Tap, SelectTool):
 
     .. note::
         Selections can be comprised of multiple regions, even those
-        made by different selection tools. Hold down the <<shift>> key
+        made by different selection tools. Hold down the SHIFT key
         while making a selection to append the new selection to any
         previous selection that might exist.
 
@@ -1256,16 +1293,16 @@ class HoverTool(InspectTool):
     according to the "datetime" formatting scheme. The following schemes are
     available:
 
-    :``"numeral"``:
+    :"numeral":
         Provides a wide variety of formats for numbers, currency, bytes, times,
         and percentages. The full set of formats can be found in the
         |NumeralTickFormatter| reference documentation.
 
-    :``"datetime"``:
+    :"datetime":
         Provides formats for date and time values. The full set of formats is
         listed in the |DatetimeTickFormatter| reference documentation.
 
-    :``"printf"``:
+    :"printf":
         Provides formats similar to C-style "printf" type specifiers. See the
         |PrintfTickFormatter| reference documentation for complete details.
 
@@ -1296,10 +1333,19 @@ class HoverTool(InspectTool):
 
     line_policy = Enum("prev", "next", "nearest", "interp", "none",
                        default="nearest", help="""
-    When showing tooltips for lines, designates whether the tooltip position
-    should be the "previous" or "next" points on the line, the "nearest" point
-    to the current mouse position, or "interpolate" along the line to the
-    current mouse position.
+    Specifies where the tooltip will be positioned when hovering over line
+    glyphs:
+
+    :"prev": between the nearest two adjacent line points, positions the
+        tooltip at the point with the lower ("previous") index
+    :"next": between the nearest two adjacent line points, positions the
+        tooltip at the point with the higher ("next") index
+    :"nearest": between the nearest two adjacent line points, positions the
+        tooltip on the point that is nearest to the mouse cursor location
+    :"interp": positions the tooltip at an interpolated point on the segment
+        joining the two nearest adjacent line points.
+    :"none": positions the tooltip directly under the mouse cursor location
+
     """)
 
     anchor = Enum(Anchor, default="center", help="""
@@ -1318,7 +1364,7 @@ class HoverTool(InspectTool):
     """)
 
 DEFAULT_HELP_TIP = "Click the question mark to learn more about Bokeh plot tools."
-DEFAULT_HELP_URL = "https://docs.bokeh.org/en/latest/docs/user_guide/tools.html"
+DEFAULT_HELP_URL = "https://docs.bokeh.org/en/latest/docs/user_guide/interaction/tools.html"
 
 class HelpTool(ActionTool):
     ''' A button tool to provide a "help" link to users.
@@ -1392,7 +1438,7 @@ class EditTool(GestureTool):
     def __init__(self, *args, **kwargs) -> None:
         super().__init__(*args, **kwargs)
 
-    empty_value = Required(Either(Bool, Int, Float, Date, Datetime, Color, String), help="""
+    empty_value = Either(Bool, Int, Float, Date, Datetime, Color, String, default=0, help="""
     Defines the value to insert on non-coordinate columns when a new
     glyph is inserted into the ``ColumnDataSource`` columns, e.g. when a
     circle glyph defines 'x', 'y' and 'color' columns, adding a new
@@ -1453,17 +1499,17 @@ class BoxEditTool(EditTool, Drag, Tap):
     * Move box: Click and drag an existing box, the box will be dropped once
       you let go of the mouse button.
 
-    * Delete box: Tap a box to select it then press <<backspace>> key while the
+    * Delete box: Tap a box to select it then press BACKSPACE key while the
       mouse is within the plot area.
 
     To **Move** or **Delete** multiple boxes at once:
 
-    * Move selection: Select box(es) with <<shift>>+tap (or another selection
+    * Move selection: Select box(es) with SHIFT+tap (or another selection
       tool) then drag anywhere on the plot. Selecting and then dragging on a
       specific box will move both.
 
-    * Delete selection: Select box(es) with <<shift>>+tap (or another selection
-      tool) then press <<backspace>> while the mouse is within the plot area.
+    * Delete selection: Select box(es) with SHIFT+tap (or another selection
+      tool) then press BACKSPACE while the mouse is within the plot area.
 
     .. |box_edit_icon| image:: /_images/icons/BoxEdit.png
         :height: 24px
@@ -1527,7 +1573,7 @@ class PointDrawTool(EditTool, Drag, Tap):
     * Move point: Tap and drag an existing point, the point will be
       dropped once you let go of the mouse button.
 
-    * Delete point: Tap a point to select it then press <<backspace>>
+    * Delete point: Tap a point to select it then press BACKSPACE
       key while the mouse is within the plot area.
 
     .. |point_draw_icon| image:: /_images/icons/PointDraw.png
@@ -1586,13 +1632,13 @@ class PolyDrawTool(PolyTool, Drag, Tap):
 
     * Add patch or multi-line: Double tap to add the first vertex, then use tap
       to add each subsequent vertex, to finalize the draw action double tap to
-      insert the final vertex or press the <<esc> key.
+      insert the final vertex or press the ESC key.
 
-    * Move patch or ulti-line: Tap and drag an existing patch/multi-line, the
+    * Move patch or multi-line: Tap and drag an existing patch/multi-line, the
       point will be dropped once you let go of the mouse button.
 
     * Delete patch or multi-line: Tap a patch/multi-line to select it then
-      press <<backspace>> key while the mouse is within the plot area.
+      press BACKSPACE key while the mouse is within the plot area.
 
     .. |poly_draw_icon| image:: /_images/icons/PolyDraw.png
         :height: 24px
@@ -1641,7 +1687,7 @@ class FreehandDrawTool(EditTool, Drag, Tap):
     * Draw vertices: Click and drag to draw a line
 
     * Delete patch/multi-line: Tap a patch/multi-line to select it then press
-      <<backspace>> key while the mouse is within the plot area.
+      BACKSPACE key while the mouse is within the plot area.
 
     .. |freehand_draw_icon| image:: /_images/icons/FreehandDraw.png
         :height: 24px
@@ -1689,12 +1735,12 @@ class PolyEditTool(PolyTool, Drag, Tap):
 
     * Add vertex: Double tap an existing vertex to select it, the tool will
       draw the next point, to add it tap in a new location. To finish editing
-      and add a point double tap otherwise press the <<esc> key to cancel.
+      and add a point double tap otherwise press the ESC key to cancel.
 
     * Move vertex: Drag an existing vertex and let go of the mouse button to
       release it.
 
-    * Delete vertex: After selecting one or more vertices press <<backspace>>
+    * Delete vertex: After selecting one or more vertices press BACKSPACE
       while the mouse cursor is within the plot area.
 
     .. |poly_edit_icon| image:: /_images/icons/PolyEdit.png
