@@ -1,5 +1,5 @@
 #-----------------------------------------------------------------------------
-# Copyright (c) 2012 - 2022, Anaconda, Inc., and Bokeh Contributors.
+# Copyright (c) 2012 - 2023, Anaconda, Inc., and Bokeh Contributors.
 # All rights reserved.
 #
 # The full license is in the file LICENSE.txt, distributed with this software.
@@ -32,21 +32,21 @@ import datetime as dt
 import uuid
 from functools import lru_cache
 from threading import Lock
-from typing import TYPE_CHECKING, Any, Type
+from typing import TYPE_CHECKING, Any
 
 # External imports
 import numpy as np
-from typing_extensions import TypeGuard
-
-if TYPE_CHECKING:
-    import numpy.typing as npt
-    import pandas as pd
 
 # Bokeh imports
 from ..core.types import ID
 from ..settings import settings
 from .strings import format_docstring
 
+if TYPE_CHECKING:
+    import numpy.typing as npt
+    import pandas as pd
+    from typing_extensions import TypeGuard
+
 #-----------------------------------------------------------------------------
 # Globals and constants
 #-----------------------------------------------------------------------------
@@ -96,6 +96,7 @@ __all__ = (
     'convert_timedelta_type',
     'is_datetime_type',
     'is_timedelta_type',
+    'make_globally_unique_css_safe_id',
     'make_globally_unique_id',
     'make_id',
     'transform_array',
@@ -277,6 +278,26 @@ def make_globally_unique_id() -> ID:
     '''
     return ID(str(uuid.uuid4()))
 
+def make_globally_unique_css_safe_id() -> ID:
+    ''' Return a globally unique CSS-safe UUID.
+
+    Some situations, e.g. id'ing dynamically created Divs in HTML documents,
+    always require globally unique IDs. ID generated with this function can
+    be used in APIs like ``document.querySelector("#id")``.
+
+    Returns:
+        str
+
+    '''
+    max_iter = 100
+
+    for _i in range(0, max_iter):
+        id = make_globally_unique_id()
+        if id[0].isalpha():
+            return id
+
+    return ID(f"bk-{make_globally_unique_id()}")
+
 def array_encoding_disabled(array: npt.NDArray[Any]) -> bool:
     ''' Determine whether an array may be binary encoded.
 
@@ -318,7 +339,7 @@ def transform_array(array: npt.NDArray[Any]) -> npt.NDArray[Any]:
     # XXX: as long as we can't support 64-bit integers, try to convert
     # to 32-bits. If not possible, let the serializer convert to a less
     # efficient representation and/or deal with any error messaging.
-    def _cast_if_can(array: npt.NDArray[Any], dtype: Type[Any]) -> npt.NDArray[Any]:
+    def _cast_if_can(array: npt.NDArray[Any], dtype: type[Any]) -> npt.NDArray[Any]:
         info = np.iinfo(dtype)
 
         if np.any((array < info.min) | (info.max < array)):
@@ -338,7 +359,7 @@ def transform_array(array: npt.NDArray[Any]) -> npt.NDArray[Any]:
 
     return array
 
-def transform_series(series: pd.Series[Any] | pd.Index) -> npt.NDArray[Any]:
+def transform_series(series: pd.Series[Any] | pd.Index | pd.api.extensions.ExtensionArray) -> npt.NDArray[Any]:
     ''' Transforms a Pandas series into serialized form
 
     Args:
@@ -355,7 +376,7 @@ def transform_series(series: pd.Series[Any] | pd.Index) -> npt.NDArray[Any]:
     if isinstance(series, pd.PeriodIndex):
         vals = series.to_timestamp().values  # type: ignore
     else:
-        vals = series.values
+        vals = series.to_numpy()
     return vals
 
 #-----------------------------------------------------------------------------
