@@ -1,5 +1,5 @@
 #-----------------------------------------------------------------------------
-# Copyright (c) 2012 - 2022, Anaconda, Inc., and Bokeh Contributors.
+# Copyright (c) 2012 - 2023, Anaconda, Inc., and Bokeh Contributors.
 # All rights reserved.
 #
 # The full license is in the file LICENSE.txt, distributed with this software.
@@ -39,6 +39,7 @@ from typing import TYPE_CHECKING, Any, Dict
 # Bokeh imports
 from ..core.types import ID
 from ..settings import settings
+from .warnings import warn
 
 if TYPE_CHECKING:
     from typing_extensions import TypeAlias
@@ -238,7 +239,7 @@ class _BytesEncoder(json.JSONEncoder):
 
 class _BytesDecoder(json.JSONDecoder):
     def __init__(self, *args: Any, **kwargs: Any) -> None:
-        super().__init__(object_hook=self.bytes_object_hook, *args, **kwargs)
+        super().__init__(*args, object_hook=self.bytes_object_hook, **kwargs)
 
     def bytes_object_hook(self, obj: dict[Any, Any]) -> Any:
         if set(obj.keys()) == {"bytes"}:
@@ -256,13 +257,12 @@ def _get_sysrandom() -> tuple[Any, bool]:
         using_sysrandom = True
         return sysrandom, using_sysrandom
     except NotImplementedError:
-        import warnings
-        warnings.warn('A secure pseudo-random number generator is not available '
-                      'on your system. Falling back to Mersenne Twister.')
+        warn('A secure pseudo-random number generator is not available '
+             'on your system. Falling back to Mersenne Twister.')
         if settings.secret_key() is None:
-            warnings.warn('A secure pseudo-random number generator is not available '
-                          'and no BOKEH_SECRET_KEY has been set. Setting a secret '
-                          'key will mitigate the lack of a secure generator.')
+            warn('A secure pseudo-random number generator is not available '
+                 'and no BOKEH_SECRET_KEY has been set. Setting a secret '
+                 'key will mitigate the lack of a secure generator.')
         using_sysrandom = False
         return random, using_sysrandom
 
@@ -284,7 +284,7 @@ def _reseed_if_needed(using_sysrandom: bool, secret_key: bytes | None) -> None:
         # time a random string is required. This may change the
         # properties of the chosen random sequence slightly, but this
         # is better than absolute predictability.
-        data = f"{random.getstate()}{time.time()}{secret_key!s}".encode('utf-8')
+        data = f"{random.getstate()}{time.time()}{secret_key!s}".encode()
         random.seed(hashlib.sha256(data).digest())
 
 
